#################################################################
##                                                             ##
##   (c) Luiz Fernando Assis <luizffga@gmail.com>              ##
##                                                             ##
##                                                             ##
##       University of São Paulo (USP)                         ##
##                                                             ##
##                                                             ##
##   R script for analyzing AGORA-DSM performance              ##
##                                                             ##
##                                                             ##
##  Assis, L.F.F.G., et al. "A Service-Oriented Middleware     ##
##  for Integrated Management of Crowdsourced and Sensor Data  ## 
##  Streams in Disaster Management". Sensors (2018).           ##
##                                                             ##
#################################################################

# load packages installing when necessary
require(tm)
require(wordcloud)
require(RColorBrewer)

# get current path only using RStudio
path <-dirname(rstudioapi::getSourceEditorContext()$path)
aux <- read.csv(paste0(path, "/crowdsourcing/reports.csv"), "sep" = ",")

# casting to dataframe
auxDS<-data.frame(aux[,5:6])

# Calculate Corpus
auxDS.Corpus<-Corpus(VectorSource(auxDS$DESCRIPTION))

# Data Cleaning and Wrangling
auxDS.Clean<-tm_map(auxDS.Corpus, PlainTextDocument)
auxDS.Clean<-tm_map(auxDS.Corpus, tolower)
auxDS.Clean<-tm_map(auxDS.Clean, removeNumbers)
auxDS.Clean<-tm_map(auxDS.Clean, removeWords, stopwords("portuguese"))
auxDS.Clean<-tm_map(auxDS.Clean, removePunctuation)
auxDS.Clean<-tm_map(auxDS.Clean, stripWhitespace)
auxDS.Clean<-tm_map(auxDS.Clean, stemDocument)

# drawing worcloud
wordcloud(words = auxDS.Clean, min.freq = 1, random.order=FALSE, rot.per=0.35, colors=brewer.pal(8, "Dark2"))
