#################################################################
##                                                             ##
##   (c) Luiz Fernando Assis <luizffga@gmail.com>              ##
##                                                             ##
##                                                             ##
##       University of São Paulo (USP)                         ##
##                                                             ##
##                                                             ##
##   R script for analyzing AGORA-DSM performance              ##
##                                                             ##
##                                                             ##
##  Assis, L.F.F.G., et al. "A Service-Oriented Middleware     ##
##  for Integrated Management of Crowdsourced and Sensor Data  ## 
##  Streams in Disaster Management". Sensors (2018).           ##
##                                                             ##
#################################################################

# load packages installing when necessary
require(dplyr)
require(reshape2)
require(RColorBrewer)

# get current path only using RStudio
path <-dirname(rstudioapi::getSourceEditorContext()$path)
aux <- read.csv(paste0(path, "/crowdsourcing/reports.csv"), "sep" = ",")

# get all locations
loc <- as.character(aux$LOCATION)

# get incident dates
time <- aux$INCIDENT.DATE
time <- as.POSIXct(as.character(time), format="%Y-%m-%d")

# build data.frames
df <- data.frame(time, loc)
df <- count(df, loc, time)

# building data to heatmap
new_data <- dcast(df, loc ~ time)
new_data[is.na(new_data)] <- 0
rownames(new_data) <- new_data$loc

# casting to matrix
new_data.m <- as.matrix(new_data[,2:ncol(new_data)])
heatmap(new_data.m, Colv = NA, Rowv = NA, scale="column",  col= colorRampPalette(brewer.pal(8, "Blues"))(25), main = "# of Flood Citizen Observations - Incident Date x Location Name", verbose)

