#################################################################
##                                                             ##
##   (c) Luiz Fernando Assis <luizffga@gmail.com>              ##
##                                                             ##
##                                                             ##
##       University of São Paulo (USP)                         ##
##                                                             ##
##                                                             ##
##   R script for analyzing AGORA-DSM performance              ##
##                                                             ##
##                                                             ##
##  Assis, L.F.F.G., et al. "A Service-Oriented Middleware     ##
##  for Integrated Management of Crowdsourced and Sensor Data  ## 
##  Streams in Disaster Management". Sensors (2018).           ##
##                                                             ##
#################################################################

# load packages installing when necessary
require(dplyr)
require(tidyr)
require(reshape2)
require(ggplot2)

# choose scenario number (e.g., one, two, three and fourth)
scenario <- "two"

# load config variables
path <-dirname(rstudioapi::getSourceEditorContext()$path)
source(paste(path, "/scenario-", scenario, "/config.R", sep = ""))

# read from csv
time_behaviour_obj <- read.csv(paste(path,"/scenario-", scenario, "/AGORA-DSM-performance-tracking.csv", sep = ""), sep = ";")

# define csv header column names
names(time_behaviour_obj) <- h

### processing time by states

# initialize variables
complete_df <- data.frame()
state_obj <- list()

# for each state get time processing behaviour
for (i in 1:length(states)) {
  
  aux_obj <- subset(time_behaviour_obj, grepl(paste("-", states[i], sep=""), place))
  
  if (nrow(aux_obj) != 0) {
    initialTime <- as.POSIXct(aux_obj[1,]$`date-time`)
    finalTime <- as.POSIXct(aux_obj[nrow(aux_obj),]$`date-time`)
    TIME <- seq(initialTime, finalTime, length.out = nrow(aux_obj))
    state_obj[[states[i]]] <- data.frame(TIME, SEC = aux_obj$`result-seg`*base_experiment)
  }
  
}

# build plot
ggplot(bind_rows(state_obj, .id="df"), aes(TIME, SEC, colour=df)) +
  geom_point() +
  labs(title = "Processing Time by States\n", x = "Experiment Time", y = "Processing Time (s)", color = "States Acronym \n in Brazil\n") +
  theme(plot.title = element_text(hjust = 0.5))

### national scenario

# define csv header column names
aux_obj <- time_behaviour_obj
aux_obj$`result-seg` <- time_behaviour_obj$`result-seg`*base_experiment

# build time series
initialTime <- as.POSIXct(aux_obj[1,]$`date-time`)
finalTime <- as.POSIXct(aux_obj[nrow(aux_obj),]$`date-time`)
TIME <- seq(initialTime, finalTime, length.out = nrow(aux_obj))

# build data frame with time processing and date time 
complete_df <- data.frame(TIME, SEC = aux_obj$`result-seg`)

# build data frame to plot
gather_df <- gather(complete_df, SEC)

# plot 
ggplot(gather_df, aes(TIME, SEC)) +
  geom_point() +                   # Use hollow circles
  geom_smooth(level=0.95) +    # Add a loess smoothed fit curve with confidence region
  labs(title = "Processing Time for the whole country of Brazil\n", x = "Experiment Time", y = "Processing Time (s)") +
  theme(plot.title = element_text(hjust = 0.5))
