#################################################################
##                                                             ##
##   (c) Luiz Fernando Assis <luizffga@gmail.com>              ##
##                                                             ##
##                                                             ##
##       University of São Paulo (USP)                         ##
##                                                             ##
##                                                             ##
##   R script for analyzing AGORA-DSM performance              ##
##                                                             ##
##                                                             ##
##  Assis, L.F.F.G., et al. "A Service-Oriented Middleware     ##
##  for Integrated Management of Crowdsourced and Sensor Data  ## 
##  Streams in Disaster Management". Sensors (2018).           ##
##                                                             ##
#################################################################

# load packages installing when necessary
require(ggplot2)
require(plyr)

# choose scenario number (e.g., one, two, three and fourth)
scenario <- "two"

# load config variables
path <-dirname(rstudioapi::getSourceEditorContext()$path)
source(paste(path, "/scenario-", scenario, "/config.R", sep = ""))

# read from csv
time_behaviour_obj <- read.csv(paste("./scenario-", scenario, "/AGORA-DSM-performance-tracking.csv", sep = ""), sep = ";")

# define csv header column names
names(time_behaviour_obj) <- h

# define auxiliary variable
aux_obj <- time_behaviour_obj

# build dataframes for time frequencies analysis
x <- as.character(aux_obj$`date-time`)
aux <- x[1]
count <- 1
element <- 1
complete_df <- data.frame(id = numeric(), x = character(), freq = numeric(), stringsAsFactors=FALSE)
for (i in 2:length(x)) {
  if (aux == x[i])
    count = count + 1
  else {
    complete_df[element,] = c(element, aux, count)
    element = element + 1
    aux = x[i]
    count = 1
  } 
}

# group values for analysis
complete_df[element,] = c(element, aux, count)
complete_df$freq <- as.numeric(complete_df$freq)
complete_df$id = as.numeric(complete_df$id)

# plot time frequency for national analysis
ggplot(complete_df, aes(x=id, y = freq)) +
  geom_bar(stat="identity") +
  labs(x = "Experiment Time", y = "Number of requests") + 
  scale_x_discrete(breaks=c(as.integer(2*nrow(complete_df)/5), 
                            as.integer(3*nrow(complete_df)/5), 
                            as.integer(4*nrow(complete_df)/5)), 
                   labels = c(complete_df[as.integer(2*nrow(complete_df)/5),]$x, 
                              complete_df[as.integer(3*nrow(complete_df)/5),]$x, 
                              complete_df[as.integer(4*nrow(complete_df)/5),]$x))

# plot time frequency for state analysis
ggplot(complete_df, aes(x=id, y = freq)) +
  geom_bar(stat="identity") +
  labs(x = "Experiment Time", y = "Number of requests") + 
  scale_x_continuous(breaks=c(as.integer(1*nrow(complete_df)/5), 
                              as.integer(2.5*nrow(complete_df)/5), 
                              as.integer(4*nrow(complete_df)/5)), 
                     labels = c(complete_df[as.integer(1*nrow(complete_df)/5),]$x, 
                                complete_df[as.integer(2.5*nrow(complete_df)/5),]$x, 
                                complete_df[as.integer(4*nrow(complete_df)/5),]$x))
